worpler

package module
v0.0.0-...-634cb92 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 26, 2022 License: MIT Imports: 3 Imported by: 0

README

worpler

Wordle guess proposals

Documentation

Index

Constants

This section is empty.

Variables

var WordlistAnswers5 = []string{}/* 2315 elements not displayed */
var WordlistAnswers5_DE = []string{}/* 6832 elements not displayed */

Functions

func Find

func Find(pattern string, exclude string, include string) []string

Find finds all words mathing pattern, exluding those, which contain chars of exclude, and exclude those which don't containschars of include. Find is case-insensitive.

func FindV2

func FindV2(list []string, pattern string, exclude string) []string

Find finds all words matching pattern, exluding those, which contain chars of "exclude" Uppercase letters in pattern means, that they are already at their designation position Lowercase letters in pattern means, that they occur in the answer, but on a different position

Types

This section is empty.

Directories

Path Synopsis
cmd
letters command
worpler command
worplerde command

Jump to